@@ -1,3 +1,7 @@
+"""Top-level dcqc module."""
+
+# isort: skip_file
+
 from importlib.metadata import PackageNotFoundError, version  # pragma: no cover
 
 try:
@@ -12,7 +16,13 @@ import logging
 
 from fs.opener import registry
 
+# Import suites to ensure that they are defined and thus discoverable
+# It is located here to avoid a circular import
+from dcqc.suites import suite_abc
+from dcqc.suites import suites
+
 from dcqc.filesystems.openers import SynapseFSOpener
+from dcqc.filesystems.synapsefs import SynapseFS
 
 # Set default logging handler to avoid "No handler found" warnings
 logging.getLogger(__name__).addHandler(logging.NullHandler())
