@@ -4,11 +4,11 @@ import os
 import re
 import shutil
 import threading
-from collections.abc import Collection
+from collections.abc import Collection, Mapping
 from contextlib import contextmanager
 from pathlib import Path, PurePosixPath
 from tempfile import NamedTemporaryFile, TemporaryDirectory, mkdtemp
-from typing import TYPE_CHECKING, Any, BinaryIO, Optional, Type
+from typing import Any, BinaryIO, Generator, Optional, Type
 
 from fs import ResourceType
 from fs.base import FS
@@ -35,12 +35,11 @@ from synapseclient.entity import Entity, File, Folder, Project, is_container
 
 from dcqc.filesystems.remote_file import RemoteFile
 
-if TYPE_CHECKING:
-    from fs.info import RawInfo
+RawInfo = Mapping[str, Mapping[str, object]]
 
 
 @contextmanager
-def synapse_errors(path):
+def synapse_errors(path: str) -> Generator:
     """A context manager for mapping ``synapseclient`` errors to ``fs`` errors."""
     try:
         yield
@@ -57,18 +56,7 @@ def synapse_errors(path):
 
 
 class SynapseFS(FS):
-    """Construct a Synapse filesystem for
-    `PyFilesystem <https://pyfilesystem.org>`_
-
-    Args:
-        root (str, optional): Synapse ID for a project or folder.
-            Defaults to None (rootless mode).
-        auth_token (str, optional): Synapse personal access token.
-            Defaults to None.
-        synapse_args (dict, optional): Dictionary of
-            arguments to pass to the ``Synapse()`` class.
-            Defaults to None.
-    """
+    """A file system-like interface for Synapse."""
 
     NULL_BYTE = b"\x00"
 
@@ -102,6 +90,17 @@ class SynapseFS(FS):
         auth_token: Optional[str] = None,
         synapse_args: Optional[dict[str, Any]] = None,
     ) -> None:
+        """Construct a Synapse filesystem for
+        `PyFilesystem <https://pyfilesystem.org>`_
+
+        Args:
+            root: Synapse ID for a project or folder.
+                Defaults to None (rootless mode).
+            auth_token: Synapse personal access token.
+                Defaults to None.
+            synapse_args: Dictionary of arguments to pass to
+                the ``Synapse`` class. Defaults to None.
+        """
         super(SynapseFS, self).__init__()
         self.auth_token = auth_token
         self.synapse_args = synapse_args or self.DEFAULT_SYNAPSE_ARGS
@@ -116,12 +115,13 @@ class SynapseFS(FS):
             Synapse: Authenticated Synapse client
         """
         if not hasattr(self._local, "synapse"):
-            # Override cache with temporary directory to avoid unwanted side effects
+            # Override cache with temporary directory
             self.synapse_args["cache_root_dir"] = mkdtemp()
             synapse = Synapse(**self.synapse_args)
             synapse.login(authToken=self.auth_token)
             self._local.synapse = synapse
-        # Clear the Synapse cache to ensure up-to-date
+        # Clear the Synapse cache to avoid unwanted side effects. More info here:
+        # https://github.com/Sage-Bionetworks-Workflows/py-dcqc/pull/3#discussion_r1068443214
         self._local.synapse.cache.purge(after_date=0)
         return self._local.synapse
 
@@ -154,7 +154,7 @@ class SynapseFS(FS):
             if not self.is_synapse_id(root):
                 raise CreateFailed(error_message)
         else:  # num_root_parts > 1
-            starting_entity, _, path = root.partition("/")
+            starting_entity, _, path = root.strip("/").partition("/")
             if not self.is_synapse_id(starting_entity):
                 raise CreateFailed(error_message)
             root = self._path_to_synapse_id(path, starting_entity)
@@ -198,7 +198,7 @@ class SynapseFS(FS):
         starting_entity = starting_entity or self.root
 
         if starting_entity is None:
-            starting_entity, _, path = path.partition("/")
+            starting_entity, _, path = path.strip("/").partition("/")
             if not self.is_synapse_id(starting_entity):
                 message = (
                     f"This SynapseFS is rootless, so the 1st part ({starting_entity}) "
@@ -237,7 +237,11 @@ class SynapseFS(FS):
 
         return current_entity
 
-    def _synapse_id_to_entity(self, synapse_id: str, download_file=False) -> Entity:
+    def _synapse_id_to_entity(
+        self,
+        synapse_id: str,
+        download_file: bool = False,
+    ) -> Entity:
         """Retrieve and validate (meta)data for a Synapse entity
 
         Args:
@@ -261,7 +265,7 @@ class SynapseFS(FS):
             raise ResourceInvalid(message)
         return entity
 
-    def _path_to_entity(self, path: str, download_file=False) -> Entity:
+    def _path_to_entity(self, path: str, download_file: bool = False) -> Entity:
         """Perform the validation and retrieval steps for a Synapse entity.
 
         Arguments:
@@ -330,7 +334,8 @@ class SynapseFS(FS):
         Raises:
             ResourceNotFound: If ``path`` does not exist.
 
-        For more information regarding resource information, see :ref:`info`.
+        For more information regarding resource information,
+            see :ref:`pyfilesystem:info`.
 
         """
         self.validatepath(path)
@@ -534,7 +539,7 @@ class SynapseFS(FS):
         temp_dir = TemporaryDirectory()
         temp_path = temp_dir.name
 
-        def on_close(remote_file):
+        def on_close(remote_file: RemoteFile) -> None:
             """Called when the S3 file closes, to upload data."""
             # If the file is empty, add a null byte to bypass
             # Synapse restriction on empty files
@@ -579,7 +584,7 @@ class SynapseFS(FS):
 
         return RemoteFile(target_file, file_name, mode_obj, on_close)
 
-    def remove(self, path: str):
+    def remove(self, path: str) -> None:
         """Remove a file from the filesystem.
 
         Arguments:
@@ -600,7 +605,7 @@ class SynapseFS(FS):
 
         self.synapse.delete(entity)
 
-    def removedir(self, path: str):
+    def removedir(self, path: str) -> None:
         """Remove a directory from the filesystem.
 
         Arguments:
@@ -639,7 +644,7 @@ class SynapseFS(FS):
 
         self.synapse.delete(entity)
 
-    def setinfo(self, path: str, info: RawInfo):
+    def setinfo(self, path: str, info: RawInfo) -> None:
         """Set info on a resource.
 
         This method is the complement to `~fs.base.FS.getinfo`
